import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
import { Input } from "@/components/ui/input";
import { Textarea } from "@/components/ui/textarea";
import Link from "next/link";

export default function Home() {
  return (
    <div className="min-h-screen bg-[#17161b] text-white">
      {/* Header */}
      <header className="border-b border-gray-800 bg-[#17161b]/95 backdrop-blur sticky top-0 z-50">
        <div className="container mx-auto px-6 py-4">
          <nav className="flex items-center justify-between">
            <div className="flex items-center space-x-2">
              <img
                src="https://ext.same-assets.com/67445013/1573125802.svg"
                alt="AuthenTech Services"
                className="h-8 w-8"
              />
              <span className="text-xl font-bold">AUTHENTECH SERVICES LLC</span>
            </div>
            <div className="hidden md:flex items-center space-x-8">
              <Link href="/" className="text-red-400 hover:text-red-300 transition-colors">Home</Link>
              <a href="#solutions" className="hover:text-red-300 transition-colors">Solutions</a>
              <a href="#vision" className="hover:text-red-300 transition-colors">Vision</a>
              <a href="#get-started" className="hover:text-red-300 transition-colors">Get Started</a>
              <a href="#team" className="hover:text-red-300 transition-colors">Team</a>
            </div>
            <Button className="bg-red-500 hover:bg-red-600 text-white border-red-500">
              Get Started
            </Button>
          </nav>
        </div>
      </header>

      {/* Hero Section */}
      <section className="relative py-24 px-6 overflow-hidden">
        <div
          className="absolute inset-0 opacity-20"
          style={{
            backgroundImage: "url('https://ext.same-assets.com/67445013/285054414.jpeg')",
            backgroundSize: "cover",
            backgroundPosition: "center"
          }}
        />
        <div className="container mx-auto relative z-10">
          <div className="max-w-4xl">
            <h1 className="text-5xl md:text-7xl font-bold mb-8 leading-tight">
              Make Your Business<br />
              A Profit Powerhouse<br />
              With AI
            </h1>
            <p className="text-xl md:text-2xl mb-8 text-gray-300 max-w-3xl">
              For a limited time, take advantage of our no-obligation complementary strategy consultation
              or trial our enterprise-grade appointment scheduler, absolutely <span className="text-red-400 font-bold">FREE</span> ($3500 value).
            </p>
            <p className="text-lg mb-12 text-gray-400 max-w-3xl">
              Your competitors are already leveraging AI to cut costs, boost productivity and deliver superior
              customer experiences, let us show you what your business' AI journey could look like.
            </p>
            <Button className="bg-red-500 hover:bg-red-600 text-white text-lg px-8 py-4 h-auto">
              Schedule a Free Call
            </Button>
          </div>
        </div>
      </section>

      {/* About Section */}
      <section className="py-20 px-6 bg-[#363845]">
        <div className="container mx-auto">
          <div className="grid md:grid-cols-2 gap-12 items-center">
            <div>
              <p className="text-lg leading-relaxed text-gray-300 mb-6">
                At AuthenTech Services LLC, we understand the transformative power of artificial intelligence
                in shaping the future of your business. Our dedicated team of consultants is committed to
                guiding you through your AI journey, ensuring that your unique needs are met at every stage.
              </p>
              <p className="text-lg leading-relaxed text-gray-300">
                From identifying quick wins to exploring long-term strategies, we provide comprehensive support
                that empowers you to harness the full potential of your data. Whether you are looking to streamline
                operations, enhance decision-making, or drive innovation, we are here to help you succeed. Discover
                the benefits of a tailored AI strategy that not only meets your current challenges but also sets
                the foundation for sustainable growth.
              </p>
            </div>
            <div className="relative">
              <img
                src="https://ext.same-assets.com/67445013/3496897843.jpeg"
                alt="AI Technology"
                className="rounded-lg w-full"
              />
            </div>
          </div>
        </div>
      </section>

      {/* Welcome Section */}
      <section className="py-20 px-6 bg-[#17161b]">
        <div className="container mx-auto">
          <h2 className="text-4xl md:text-5xl font-bold mb-8 text-center">
            WELCOME TO THE ANSWER<br />
            OF BUSINESS SUCCESS.
          </h2>
          <div className="max-w-4xl mx-auto text-center">
            <p className="text-lg text-gray-300 mb-8">
              Don't let the complexities of AI and how to leverage them for your business be a blocker.
              We take away the difficulties with our expert consulting services. We provide easy, cost-effective
              strategies to move your business forward. Through strategic AI adoption.
            </p>
            <p className="text-lg text-gray-300 mb-8">
              Your business can achieve unprecedented growth and efficiency in a multitude of areas - marketing,
              optimization, customer engagement, and much more.
            </p>
            <p className="text-lg text-gray-300">
              We empower your business with AI to become a reliable non-stop powerhouse employee. We can provide
              chat-bots, websites, rebranding, social media marketing, ad automation and much more.
            </p>
          </div>
        </div>
      </section>

      {/* Services Section */}
      <section id="solutions" className="py-20 px-6 bg-[#363845]">
        <div className="container mx-auto">
          <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-8">
            {/* AI Strategy */}
            <Card className="bg-[#17161b] border-gray-700 hover:border-red-500 transition-colors">
              <CardContent className="p-8 text-center">
                <img
                  src="https://ext.same-assets.com/67445013/2313667500.svg"
                  alt="AI Strategy"
                  className="h-16 w-16 mx-auto mb-6"
                />
                <h3 className="text-xl font-bold mb-4 text-blue-400">AI Strategy and Investment</h3>
                <p className="text-gray-400">
                  We identify where the best use of AI is most suitable for your business. We share our lens
                  of return on investment models and how operational efficiencies and customer interactions
                  will benefit the most.
                </p>
              </CardContent>
            </Card>

            {/* Brand & Marketing */}
            <Card className="bg-[#17161b] border-gray-700 hover:border-red-500 transition-colors">
              <CardContent className="p-8 text-center">
                <img
                  src="https://ext.same-assets.com/67445013/2986674433.svg"
                  alt="Brand Marketing"
                  className="h-16 w-16 mx-auto mb-6"
                />
                <h3 className="text-xl font-bold mb-4 text-red-400">Perfect Your Brand & Marketing Message</h3>
                <p className="text-gray-400">
                  Our design experts are here to enhance your brand's visual digital identity. We optimize
                  your logo and integrate impactful content touchpoints, driving sales conversions and
                  increasing product demand. Let us help you create a memorable brand presence that resonates
                  with your audience.
                </p>
              </CardContent>
            </Card>

            {/* Data Acceleration */}
            <Card className="bg-[#17161b] border-gray-700 hover:border-red-500 transition-colors">
              <CardContent className="p-8 text-center">
                <img
                  src="https://ext.same-assets.com/67445013/4147059485.svg"
                  alt="Data Acceleration"
                  className="h-16 w-16 mx-auto mb-6"
                />
                <h3 className="text-xl font-bold mb-4 text-blue-400">Data Acceleration</h3>
                <p className="text-gray-400">
                  We help your company curate the right data to help monetize your operations from your analytics.
                  Know where the profits are being made and lost and why!
                </p>
              </CardContent>
            </Card>

            {/* Customer Service */}
            <Card className="bg-[#17161b] border-gray-700 hover:border-red-500 transition-colors">
              <CardContent className="p-8 text-center">
                <img
                  src="https://ext.same-assets.com/67445013/2263131457.svg"
                  alt="Customer Service"
                  className="h-16 w-16 mx-auto mb-6"
                />
                <h3 className="text-xl font-bold mb-4 text-blue-400">Full Customer Service Experience</h3>
                <p className="text-gray-400">
                  As strategic advisors, we partner with you, from design concept to implementation, training
                  and support. From the chatbot for your website, to a workflow automation agent that is your
                  personalized assistant to a conversational AI call center avatar that speaks multi-languages
                  to impress your customers. Anything is possible.
                </p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Testimonials Section */}
      <section className="py-20 px-6 bg-[#17161b]">
        <div className="container mx-auto">
          <h2 className="text-4xl md:text-5xl font-bold mb-16 text-center">
            See What Our Clients Say
          </h2>
          <div className="max-w-6xl mx-auto">
            <div className="grid md:grid-cols-2 gap-12 items-center">
              <div className="relative">
                <img
                  src="https://ext.same-assets.com/67445013/2481270196.jpeg"
                  alt="Robert Proseci"
                  className="rounded-full w-80 h-80 object-cover mx-auto"
                />
              </div>
              <div>
                <blockquote className="text-xl md:text-2xl mb-6 leading-relaxed">
                  "Game-Changer for Our Business!"<br />
                  "AuthenTech Services delivered a scalable AI strategy that cut our data processing time by 60%.
                  Their team saw our gaps and where we were wasting out time and money. Outstanding partner!"
                </blockquote>
                <cite className="text-gray-400 italic">Robert Proseci, Venture Analytics Group</cite>
              </div>
            </div>
            <div className="flex justify-center mt-8 space-x-2">
              <div className="w-3 h-3 rounded-full bg-red-500" />
              <div className="w-3 h-3 rounded-full bg-gray-600" />
              <div className="w-3 h-3 rounded-full bg-gray-600" />
              <div className="w-3 h-3 rounded-full bg-gray-600" />
              <div className="w-3 h-3 rounded-full bg-gray-600" />
            </div>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="py-20 px-6 bg-[#363845]">
        <div className="container mx-auto">
          <div className="grid md:grid-cols-2 gap-12 items-center">
            <div
              className="relative rounded-lg overflow-hidden h-96"
              style={{
                backgroundImage: "url('https://ext.same-assets.com/67445013/417749315.jpeg')",
                backgroundSize: "cover",
                backgroundPosition: "center"
              }}
            >
              <div className="absolute inset-0 bg-black/60 flex items-center justify-center">
                <div className="text-center">
                  <h3 className="text-3xl font-bold mb-4">
                    Wherever you are on your<br />
                    journey, we can help. Let's<br />
                    have a conversation.
                  </h3>
                </div>
              </div>
            </div>
            <div>
              <h3 className="text-2xl font-bold mb-6">GET THE PROJECT DONE QUICKLY</h3>
              <ul className="space-y-4 mb-8">
                <li className="flex items-start">
                  <span className="text-red-500 mr-2">•</span>
                  We map out your AI Transformation journey.
                </li>
                <li className="flex items-start">
                  <span className="text-red-500 mr-2">•</span>
                  Identify the quick and long term opportunities.
                </li>
                <li className="flex items-start">
                  <span className="text-red-500 mr-2">•</span>
                  Calculate the investment and returns from the proposed solutions
                </li>
                <li className="flex items-start">
                  <span className="text-red-500 mr-2">•</span>
                  And provide on-going support so you will not be alone in the journey.
                </li>
                <li className="flex items-start">
                  <span className="text-red-500 mr-2">•</span>
                  Unlock the potential of your business data by partnering with us.
                </li>
              </ul>
              <p className="text-gray-300 mb-8">
                We bridge gaps between technical complexities and practical solutions, tailored to your needs.
                Our AI strategies strengthen operational efficiency, eliminate errors and drive sustainable growth,
                ensuring your business remains a step ahead of the competition. Your involvement is key, turning
                insights into actionable growth each step of the way.
              </p>
              <Button className="bg-red-500 hover:bg-red-600 text-white text-lg px-8 py-3">
                Schedule A Call
              </Button>
            </div>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="py-16 px-6 bg-[#17161b] border-t border-gray-800">
        <div className="container mx-auto">
          <div className="grid md:grid-cols-4 gap-8">
            {/* Company Info */}
            <div className="md:col-span-2">
              <div className="flex items-center space-x-2 mb-6">
                <img
                  src="https://ext.same-assets.com/67445013/1573125802.svg"
                  alt="AuthenTech Services"
                  className="h-8 w-8"
                />
                <span className="text-xl font-bold">AUTHENTECH SERVICES, LLC</span>
              </div>
              <div className="space-y-2 text-gray-400">
                <p>support@authentechsvcs.com</p>
                <p>3580 GH Court</p>
                <p>Bonita Springs, Fl 34134</p>
                <p>Phone +1(713) 377-8855</p>
                <p>Email - epatrick@authentechsvcs.com</p>
              </div>
            </div>

            {/* Quick Links */}
            <div>
              <h4 className="font-bold mb-4">Quick Links</h4>
              <div className="space-y-2">
                <a href="#solutions" className="block text-gray-400 hover:text-red-400 transition-colors">Solutions</a>
                <a href="#vision" className="block text-gray-400 hover:text-red-400 transition-colors">Vision</a>
                <a href="/success-stories" className="block text-gray-400 hover:text-red-400 transition-colors">Success Stories</a>
                <a href="/blog" className="block text-gray-400 hover:text-red-400 transition-colors">Blog</a>
              </div>
              <Button className="bg-red-500 hover:bg-red-600 text-white mt-4">
                Let's Talk
              </Button>
            </div>

            {/* Newsletter */}
            <div>
              <h4 className="font-bold mb-4">Subscribe to Our Newsletter</h4>
              <div className="space-y-4">
                <Input
                  type="email"
                  placeholder="Email"
                  className="bg-[#363845] border-gray-600 text-white"
                />
                <div className="flex items-center space-x-2">
                  <input type="checkbox" className="rounded" />
                  <span className="text-sm text-gray-400">Yes, subscribe me to your newsletter.</span>
                </div>
                <Button className="w-full bg-gray-700 hover:bg-gray-600">Submit</Button>
              </div>

              <div className="mt-6">
                <h5 className="font-bold mb-3">Follow Us On:</h5>
                <div className="flex space-x-3">
                  <a href="https://linkedin.com/company/authentech-services" className="block">
                    <img src="https://ext.same-assets.com/67445013/1908982482.png" alt="LinkedIn" className="w-6 h-6" />
                  </a>
                  <a href="https://facebook.com/authentech-services" className="block">
                    <img src="https://ext.same-assets.com/67445013/3527535743.png" alt="Facebook" className="w-6 h-6" />
                  </a>
                  <a href="https://twitter.com/authentech-services" className="block">
                    <img src="https://ext.same-assets.com/67445013/2678672543.png" alt="Twitter" className="w-6 h-6" />
                  </a>
                </div>
              </div>
            </div>
          </div>

          <div className="border-t border-gray-800 mt-12 pt-6 text-center text-gray-400">
            <p>© 2022 by Authentech Services Privacy and security</p>
          </div>
        </div>
      </footer>
    </div>
  );
}
